mobspy.data_handler package — MobsPy 2.2 documentation

# mobspy.data_handler package

## Submodules

## mobspy.data_handler.process_result_data module

mobspy.data_handler.process_result_data.py

Handles converting the output data from a simulation into desired-units or concentration

mobspy.data_handler.process_result_data.convert_data_to_desired_unit(data, unit_x=None, unit_y=None, output_concentration=False, volume=1)

  Converts the simulation output data from the MobsPy standard units to the desired units specified by the user

  Parameters:

    - data – (dict) resulting data from a MobsPy simulation execution

    - unit_x – (str) unit that the user desires the time in, defaults to dimensionless (None)

    - unit_y – (str) unit that the user desires the y axis to be in (Concentration or counts)

    - output_concentration – (bool) decide if output should be a concentration or count

    - volume – (float) - volume set as parameter to the simulation

  Returns:

    converted_data - input data converted to the desired units

  Return type:

    (dict) Dictionary meta-species as key and run as value

## mobspy.data_handler.time_series_object module

This module implements the class that stores the results from a MobsPy simulation

class mobspy.data_handler.time_series_object.MobsPyList_of_TS(list_of_mspy_ts, fres=False)

  Bases: `object`

  add_ts_to_data(time_series)

    Add a new time series to the TS data. Used for stochastic plotting the average and standard deviation

    Parameters:

      time_series – (dict) dictionary with species strings as keys and run as value

  get_max_time_for_species(species)

    Returns the maximum time in all the time-series stored for a given species

  return_pandas()
  to_dict()
    Returns:

      data in dict format {‘data’: …., ‘params’:….., ‘models’:…….}

class mobspy.data_handler.time_series_object.MobsPyTimeSeries(data_dict, model_parameters=None)

  Bases: `object`

## Module contents